==> Contenido_4.8.10.zip: setup/data/examples/examples_container1.sql <==
INSERT INTO !PREFIX!_container VALUES (1, 1, 1, 3);
INSERT INTO !PREFIX!_container VALUES (2, 1, 10, 22);
INSERT INTO !PREFIX!_container VALUES (3, 1, 20, 5);
INSERT INTO !PREFIX!_container VALUES (4, 1, 30, 10);
INSERT INTO !PREFIX!_container VALUES (5, 1, 40, 17);
INSERT INTO !PREFIX!_container VALUES (6, 1, 50, 6);
INSERT INTO !PREFIX!_container VALUES (7, 1, 51, 20);
INSERT INTO !PREFIX!_container VALUES (8, 1, 52, 15);
INSERT INTO !PREFIX!_container VALUES (9, 1, 53, 0);
INSERT INTO !PREFIX!_container VALUES (10, 1, 54, 0);
INSERT INTO !PREFIX!_container VALUES (11, 1, 55, 0);
INSERT INTO !PREFIX!_container VALUES (12, 1, 56, 0);
INSERT INTO !PREFIX!_container VALUES (13, 1, 57, 0);
INSERT INTO !PREFIX!_container VALUES (14, 1, 58, 0);
INSERT INTO !PREFIX!_container VALUES (15, 1, 59, 0);
INSERT INTO !PREFIX!_container VALUES (16, 1, 60, 21);
INSERT INTO !PREFIX!_container VALUES (17, 1, 70, 8);
INSERT INTO !PREFIX!_container VALUES (18, 1, 75, 11);
INSERT INTO !PREFIX!_container VALUES (19, 1, 76, 4);
INSERT INTO !PREFIX!_container VALUES (20, 1, 80, 7);
INSERT INTO !PREFIX!_container VALUES (21, 2, 1, 3);
INSERT INTO !PREFIX!_container VALUES (22, 2, 10, 22);
INSERT INTO !PREFIX!_container VALUES (23, 2, 20, 5);
INSERT INTO !PREFIX!_container VALUES (24, 2, 30, 10);
INSERT INTO !PREFIX!_container VALUES (25, 2, 40, 17);
INSERT INTO !PREFIX!_container VALUES (26, 2, 50, 6);
INSERT INTO !PREFIX!_container VALUES (27, 2, 51, 20);
INSERT INTO !PREFIX!_container VALUES (28, 2, 52, 2);
INSERT INTO !PREFIX!_container VALUES (29, 2, 53, 0);
INSERT INTO !PREFIX!_container VALUES (30, 2, 54, 0);
INSERT INTO !PREFIX!_container VALUES (31, 2, 55, 0);
INSERT INTO !PREFIX!_container VALUES (32, 2, 56, 0);
INSERT INTO !PREFIX!_container VALUES (33, 2, 57, 0);
INSERT INTO !PREFIX!_container VALUES (34, 2, 58, 0);
INSERT INTO !PREFIX!_container VALUES (35, 2, 59, 0);
INSERT INTO !PREFIX!_container VALUES (36, 2, 60, 21);
INSERT INTO !PREFIX!_container VALUES (37, 2, 70, 8);
INSERT INTO !PREFIX!_container VALUES (38, 2, 75, 11);
INSERT INTO !PREFIX!_container VALUES (39, 2, 76, 4);
INSERT INTO !PREFIX!_container VALUES (40, 2, 80, 7);
INSERT INTO !PREFIX!_container VALUES (41, 3, 1, 3);
INSERT INTO !PREFIX!_container VALUES (42, 3, 10, 22);
INSERT INTO !PREFIX!_container VALUES (43, 3, 20, 5);
INSERT INTO !PREFIX!_container VALUES (44, 3, 30, 10);
INSERT INTO !PREFIX!_container VALUES (45, 3, 40, 17);
INSERT INTO !PREFIX!_container VALUES (46, 3, 50, 6);
INSERT INTO !PREFIX!_container VALUES (47, 3, 51, 20);
INSERT INTO !PREFIX!_container VALUES (48, 3, 52, 13);
INSERT INTO !PREFIX!_container VALUES (49, 3, 53, 14);
INSERT INTO !PREFIX!_container VALUES (50, 3, 54, 0);
INSERT INTO !PREFIX!_container VALUES (51, 3, 55, 0);
INSERT INTO !PREFIX!_container VALUES (52, 3, 56, 0);
INSERT INTO !PREFIX!_container VALUES (53, 3, 57, 0);
INSERT INTO !PREFIX!_container VALUES (54, 3, 58, 0);
INSERT INTO !PREFIX!_container VALUES (55, 3, 59, 0);
INSERT INTO !PREFIX!_container VALUES (56, 3, 60, 21);
INSERT INTO !PREFIX!_container VALUES (57, 3, 70, 8);
INSERT INTO !PREFIX!_container VALUES (58, 3, 75, 11);
INSERT INTO !PREFIX!_container VALUES (59, 3, 76, 4);
INSERT INTO !PREFIX!_container VALUES (60, 3, 80, 7);
INSERT INTO !PREFIX!_container VALUES (61, 4, 1, 3);
INSERT INTO !PREFIX!_container VALUES (62, 4, 10, 22);
INSERT INTO !PREFIX!_container VALUES (63, 4, 20, 5);
INSERT INTO !PREFIX!_container VALUES (64, 4, 30, 10);
INSERT INTO !PREFIX!_container VALUES (65, 4, 40, 17);
INSERT INTO !PREFIX!_container VALUES (66, 4, 50, 6);
INSERT INTO !PREFIX!_container VALUES (67, 4, 51, 20);
INSERT INTO !PREFIX!_container VALUES (68, 4, 52, 12);
INSERT INTO !PREFIX!_container VALUES (69, 4, 53, 0);
INSERT INTO !PREFIX!_container VALUES (70, 4, 54, 0);
INSERT INTO !PREFIX!_container VALUES (71, 4, 55, 0);
INSERT INTO !PREFIX!_container VALUES (72, 4, 56, 0);
INSERT INTO !PREFIX!_container VALUES (73, 4, 57, 0);
INSERT INTO !PREFIX!_container VALUES (74, 4, 58, 0);
INSERT INTO !PREFIX!_container VALUES (75, 4, 59, 0);
INSERT INTO !PREFIX!_container VALUES (76, 4, 60, 21);
INSERT INTO !PREFIX!_container VALUES (77, 4, 70, 8);
INSERT INTO !PREFIX!_container VALUES (78, 4, 75, 11);
INSERT INTO !PREFIX!_container VALUES (79, 4, 76, 4);
INSERT INTO !PREFIX!_container VALUES (80, 4, 80, 7);
INSERT INTO !PREFIX!_container VALUES (81, 5, 1, 3);
INSERT INTO !PREFIX!_container VALUES (82, 5, 10, 22);
INSERT INTO !PREFIX!_container VALUES (83, 5, 20, 5);
INSERT INTO !PREFIX!_container VALUES (84, 5, 30, 10);
INSERT INTO !PREFIX!_container VALUES (85, 5, 40, 17);
INSERT INTO !PREFIX!_container VALUES (86, 5, 50, 6);
INSERT INTO !PREFIX!_container VALUES (87, 5, 51, 20);
INSERT INTO !PREFIX!_container VALUES (88, 5, 52, 19);
INSERT INTO !PREFIX!_container VALUES (89, 5, 53, 0);
INSERT INTO !PREFIX!_container VALUES (90, 5, 54, 0);
INSERT INTO !PREFIX!_container VALUES (91, 5, 55, 0);
INSERT INTO !PREFIX!_container VALUES (92, 5, 56, 0);
INSERT INTO !PREFIX!_container VALUES (93, 5, 57, 0);
INSERT INTO !PREFIX!_container VALUES (94, 5, 58, 0);
INSERT INTO !PREFIX!_container VALUES (95, 5, 59, 0);
INSERT INTO !PREFIX!_container VALUES (96, 5, 60, 21);
INSERT INTO !PREFIX!_container VALUES (97, 5, 70, 8);
INSERT INTO !PREFIX!_container VALUES (98, 5, 75, 11);
INSERT INTO !PREFIX!_container VALUES (99, 5, 76, 4);
INSERT INTO !PREFIX!_container VALUES (100, 5, 80, 7);
INSERT INTO !PREFIX!_container VALUES (101, 6, 1, 3);
INSERT INTO !PREFIX!_container VALUES (102, 6, 10, 22);
INSERT INTO !PREFIX!_container VALUES (103, 6, 20, 5);
INSERT INTO !PREFIX!_container VALUES (104, 6, 30, 10);
INSERT INTO !PREFIX!_container VALUES (105, 6, 40, 17);
INSERT INTO !PREFIX!_container VALUES (106, 6, 50, 6);
INSERT INTO !PREFIX!_container VALUES (107, 6, 51, 20);
INSERT INTO !PREFIX!_container VALUES (108, 6, 52, 23);
INSERT INTO !PREFIX!_container VALUES (109, 6, 53, 0);
INSERT INTO !PREFIX!_container VALUES (110, 6, 54, 0);
INSERT INTO !PREFIX!_container VALUES (111, 6, 55, 0);
INSERT INTO !PREFIX!_container VALUES (112, 6, 56, 0);
INSERT INTO !PREFIX!_container VALUES (113, 6, 57, 0);
INSERT INTO !PREFIX!_container VALUES (114, 6, 58, 0);
INSERT INTO !PREFIX!_container VALUES (115, 6, 59, 0);
INSERT INTO !PREFIX!_container VALUES (116, 6, 60, 21);
INSERT INTO !PREFIX!_container VALUES (117, 6, 70, 8);
INSERT INTO !PREFIX!_container VALUES (118, 6, 75, 11);
INSERT INTO !PREFIX!_container VALUES (119, 6, 76, 4);
INSERT INTO !PREFIX!_container VALUES (120, 6, 80, 7);
INSERT INTO !PREFIX!_container VALUES (121, 7, 1, 3);
INSERT INTO !PREFIX!_container VALUES (122, 7, 10, 22);
INSERT INTO !PREFIX!_container VALUES (123, 7, 20, 5);
INSERT INTO !PREFIX!_container VALUES (124, 7, 30, 10);
INSERT INTO !PREFIX!_container VALUES (125, 7, 40, 17);
INSERT INTO !PREFIX!_container VALUES (126, 7, 50, 6);
INSERT INTO !PREFIX!_container VALUES (127, 7, 51, 20);
INSERT INTO !PREFIX!_container VALUES (128, 7, 52, 23);
INSERT INTO !PREFIX!_container VALUES (129, 7, 53, 0);
INSERT INTO !PREFIX!_container VALUES (130, 7, 54, 0);
INSERT INTO !PREFIX!_container VALUES (131, 7, 55, 0);
INSERT INTO !PREFIX!_container VALUES (132, 7, 56, 0);
INSERT INTO !PREFIX!_container VALUES (133, 7, 57, 0);
INSERT INTO !PREFIX!_container VALUES (134, 7, 58, 0);
INSERT INTO !PREFIX!_container VALUES (135, 7, 59, 0);
INSERT INTO !PREFIX!_container VALUES (136, 7, 60, 16);
INSERT INTO !PREFIX!_container VALUES (137, 7, 70, 8);
INSERT INTO !PREFIX!_container VALUES (138, 7, 75, 11);
INSERT INTO !PREFIX!_container VALUES (139, 7, 76, 4);
INSERT INTO !PREFIX!_container VALUES (140, 7, 80, 7);
INSERT INTO !PREFIX!_container VALUES (141, 8, 1, 3);
INSERT INTO !PREFIX!_container VALUES (142, 8, 10, 22);
INSERT INTO !PREFIX!_container VALUES (143, 8, 20, 5);
INSERT INTO !PREFIX!_container VALUES (144, 8, 30, 10);
INSERT INTO !PREFIX!_container VALUES (145, 8, 40, 17);
INSERT INTO !PREFIX!_container VALUES (146, 8, 50, 6);
INSERT INTO !PREFIX!_container VALUES (147, 8, 51, 20);
INSERT INTO !PREFIX!_container VALUES (148, 8, 52, 18);
INSERT INTO !PREFIX!_container VALUES (149, 8, 53, 0);
INSERT INTO !PREFIX!_container VALUES (150, 8, 54, 0);
INSERT INTO !PREFIX!_container VALUES (151, 8, 55, 0);
INSERT INTO !PREFIX!_container VALUES (152, 8, 56, 0);
INSERT INTO !PREFIX!_container VALUES (153, 8, 57, 0);
INSERT INTO !PREFIX!_container VALUES (154, 8, 58, 0);
INSERT INTO !PREFIX!_container VALUES (155, 8, 59, 0);
INSERT INTO !PREFIX!_container VALUES (156, 8, 60, 21);
INSERT INTO !PREFIX!_container VALUES (157, 8, 70, 8);
INSERT INTO !PREFIX!_container VALUES (158, 8, 75, 11);
INSERT INTO !PREFIX!_container VALUES (159, 8, 76, 4);
INSERT INTO !PREFIX!_container VALUES (160, 8, 80, 7);
INSERT INTO !PREFIX!_container_conf VALUES (8, 9, 60, '0=http%3A%2F%2Fwww.contenido.org%2Frss%2Fde%2Fnews&1=teaser_right.html&2=3&');
INSERT INTO !PREFIX!_container_conf VALUES (5, 59, 52, '1=2&3=sortdate&16=asc&4=%24C52%24C52CMS_VALUE%5B4%5D&14=&15=&');
INSERT INTO !PREFIX!_container_conf VALUES (9, 43, 60, '0=http%3A%2F%2Fwww.contenido.org%2Frss%2Fde%2Fnews&1=teaser_right.html&2=3&');
INSERT INTO !PREFIX!_container_conf VALUES (10, 50, 52, '0=1&1=5&');
INSERT INTO !PREFIX!_container_conf VALUES (11, 34, 52, '0=1&1=5&');
INSERT INTO !PREFIX!_container_conf VALUES (13, 60, 60, '0=http%3A%2F%2Fwww.contenido.org%2Frss%2Fde%2Fnews&1=teaser_right.html&2=3&');
INSERT INTO !PREFIX!_container_conf VALUES (15, 16, 52, '0=180&1=180&2=2&3=2&4=&5=bildergalerie%2F&');
INSERT INTO !PREFIX!_container_conf VALUES (16, 31, 52, '0=&2=&1=&3=&4=sendmail&5=&6=&7=&');
INSERT INTO !PREFIX!_container_conf VALUES (17, 47, 52, '0=&2=&1=&3=&4=sendmail&5=&6=&7=&');

==> Contenido_4.8.12.zip: setup/data/examples/examples_container1.sql <==
INSERT INTO !PREFIX!_container VALUES (1, 1, 1, 3);
INSERT INTO !PREFIX!_container VALUES (2, 1, 10, 22);
INSERT INTO !PREFIX!_container VALUES (3, 1, 20, 5);
INSERT INTO !PREFIX!_container VALUES (4, 1, 30, 10);
INSERT INTO !PREFIX!_container VALUES (5, 1, 40, 17);
INSERT INTO !PREFIX!_container VALUES (6, 1, 50, 6);
INSERT INTO !PREFIX!_container VALUES (7, 1, 51, 20);
INSERT INTO !PREFIX!_container VALUES (8, 1, 52, 15);
INSERT INTO !PREFIX!_container VALUES (9, 1, 53, 0);
INSERT INTO !PREFIX!_container VALUES (10, 1, 54, 0);
INSERT INTO !PREFIX!_container VALUES (11, 1, 55, 0);
INSERT INTO !PREFIX!_container VALUES (12, 1, 56, 0);
INSERT INTO !PREFIX!_container VALUES (13, 1, 57, 0);
INSERT INTO !PREFIX!_container VALUES (14, 1, 58, 0);
INSERT INTO !PREFIX!_container VALUES (15, 1, 59, 0);
INSERT INTO !PREFIX!_container VALUES (16, 1, 60, 21);
INSERT INTO !PREFIX!_container VALUES (17, 1, 70, 8);
INSERT INTO !PREFIX!_container VALUES (18, 1, 75, 11);
INSERT INTO !PREFIX!_container VALUES (19, 1, 76, 4);
INSERT INTO !PREFIX!_container VALUES (20, 1, 80, 7);
INSERT INTO !PREFIX!_container VALUES (21, 2, 1, 3);
INSERT INTO !PREFIX!_container VALUES (22, 2, 10, 22);
INSERT INTO !PREFIX!_container VALUES (23, 2, 20, 5);
INSERT INTO !PREFIX!_container VALUES (24, 2, 30, 10);
INSERT INTO !PREFIX!_container VALUES (25, 2, 40, 17);
INSERT INTO !PREFIX!_container VALUES (26, 2, 50, 6);
INSERT INTO !PREFIX!_container VALUES (27, 2, 51, 20);
INSERT INTO !PREFIX!_container VALUES (28, 2, 52, 2);
INSERT INTO !PREFIX!_container VALUES (29, 2, 53, 0);
INSERT INTO !PREFIX!_container VALUES (30, 2, 54, 0);
INSERT INTO !PREFIX!_container VALUES (31, 2, 55, 0);
INSERT INTO !PREFIX!_container VALUES (32, 2, 56, 0);
INSERT INTO !PREFIX!_container VALUES (33, 2, 57, 0);
INSERT INTO !PREFIX!_container VALUES (34, 2, 58, 0);
INSERT INTO !PREFIX!_container VALUES (35, 2, 59, 0);
INSERT INTO !PREFIX!_container VALUES (36, 2, 60, 21);
INSERT INTO !PREFIX!_container VALUES (37, 2, 70, 8);
INSERT INTO !PREFIX!_container VALUES (38, 2, 75, 11);
INSERT INTO !PREFIX!_container VALUES (39, 2, 76, 4);
INSERT INTO !PREFIX!_container VALUES (40, 2, 80, 7);
INSERT INTO !PREFIX!_container VALUES (41, 3, 1, 3);
INSERT INTO !PREFIX!_container VALUES (42, 3, 10, 22);
INSERT INTO !PREFIX!_container VALUES (43, 3, 20, 5);
INSERT INTO !PREFIX!_container VALUES (44, 3, 30, 10);
INSERT INTO !PREFIX!_container VALUES (45, 3, 40, 17);
INSERT INTO !PREFIX!_container VALUES (46, 3, 50, 6);
INSERT INTO !PREFIX!_container VALUES (47, 3, 51, 20);
INSERT INTO !PREFIX!_container VALUES (48, 3, 52, 13);
INSERT INTO !PREFIX!_container VALUES (49, 3, 53, 14);
INSERT INTO !PREFIX!_container VALUES (50, 3, 54, 0);
INSERT INTO !PREFIX!_container VALUES (51, 3, 55, 0);
INSERT INTO !PREFIX!_container VALUES (52, 3, 56, 0);
INSERT INTO !PREFIX!_container VALUES (53, 3, 57, 0);
INSERT INTO !PREFIX!_container VALUES (54, 3, 58, 0);
INSERT INTO !PREFIX!_container VALUES (55, 3, 59, 0);
INSERT INTO !PREFIX!_container VALUES (56, 3, 60, 21);
INSERT INTO !PREFIX!_container VALUES (57, 3, 70, 8);
INSERT INTO !PREFIX!_container VALUES (58, 3, 75, 11);
INSERT INTO !PREFIX!_container VALUES (59, 3, 76, 4);
INSERT INTO !PREFIX!_container VALUES (60, 3, 80, 7);
INSERT INTO !PREFIX!_container VALUES (61, 4, 1, 3);
INSERT INTO !PREFIX!_container VALUES (62, 4, 10, 22);
INSERT INTO !PREFIX!_container VALUES (63, 4, 20, 5);
INSERT INTO !PREFIX!_container VALUES (64, 4, 30, 10);
INSERT INTO !PREFIX!_container VALUES (65, 4, 40, 17);
INSERT INTO !PREFIX!_container VALUES (66, 4, 50, 6);
INSERT INTO !PREFIX!_container VALUES (67, 4, 51, 20);
INSERT INTO !PREFIX!_container VALUES (68, 4, 52, 12);
INSERT INTO !PREFIX!_container VALUES (69, 4, 53, 0);
INSERT INTO !PREFIX!_container VALUES (70, 4, 54, 0);
INSERT INTO !PREFIX!_container VALUES (71, 4, 55, 0);
INSERT INTO !PREFIX!_container VALUES (72, 4, 56, 0);
INSERT INTO !PREFIX!_container VALUES (73, 4, 57, 0);
INSERT INTO !PREFIX!_container VALUES (74, 4, 58, 0);
INSERT INTO !PREFIX!_container VALUES (75, 4, 59, 0);
INSERT INTO !PREFIX!_container VALUES (76, 4, 60, 21);
INSERT INTO !PREFIX!_container VALUES (77, 4, 70, 8);
INSERT INTO !PREFIX!_container VALUES (78, 4, 75, 11);
INSERT INTO !PREFIX!_container VALUES (79, 4, 76, 4);
INSERT INTO !PREFIX!_container VALUES (80, 4, 80, 7);
INSERT INTO !PREFIX!_container VALUES (81, 5, 1, 3);
INSERT INTO !PREFIX!_container VALUES (82, 5, 10, 22);
INSERT INTO !PREFIX!_container VALUES (83, 5, 20, 5);
INSERT INTO !PREFIX!_container VALUES (84, 5, 30, 10);
INSERT INTO !PREFIX!_container VALUES (85, 5, 40, 17);
INSERT INTO !PREFIX!_container VALUES (86, 5, 50, 6);
INSERT INTO !PREFIX!_container VALUES (87, 5, 51, 20);
INSERT INTO !PREFIX!_container VALUES (88, 5, 52, 19);
INSERT INTO !PREFIX!_container VALUES (89, 5, 53, 0);
INSERT INTO !PREFIX!_container VALUES (90, 5, 54, 0);
INSERT INTO !PREFIX!_container VALUES (91, 5, 55, 0);
INSERT INTO !PREFIX!_container VALUES (92, 5, 56, 0);
INSERT INTO !PREFIX!_container VALUES (93, 5, 57, 0);
INSERT INTO !PREFIX!_container VALUES (94, 5, 58, 0);
INSERT INTO !PREFIX!_container VALUES (95, 5, 59, 0);
INSERT INTO !PREFIX!_container VALUES (96, 5, 60, 21);
INSERT INTO !PREFIX!_container VALUES (97, 5, 70, 8);
INSERT INTO !PREFIX!_container VALUES (98, 5, 75, 11);
INSERT INTO !PREFIX!_container VALUES (99, 5, 76, 4);
INSERT INTO !PREFIX!_container VALUES (100, 5, 80, 7);
INSERT INTO !PREFIX!_container VALUES (101, 6, 1, 3);
INSERT INTO !PREFIX!_container VALUES (102, 6, 10, 22);
INSERT INTO !PREFIX!_container VALUES (103, 6, 20, 5);
INSERT INTO !PREFIX!_container VALUES (104, 6, 30, 10);
INSERT INTO !PREFIX!_container VALUES (105, 6, 40, 17);
INSERT INTO !PREFIX!_container VALUES (106, 6, 50, 6);
INSERT INTO !PREFIX!_container VALUES (107, 6, 51, 20);
INSERT INTO !PREFIX!_container VALUES (108, 6, 52, 23);
INSERT INTO !PREFIX!_container VALUES (109, 6, 53, 0);
INSERT INTO !PREFIX!_container VALUES (110, 6, 54, 0);
INSERT INTO !PREFIX!_container VALUES (111, 6, 55, 0);
INSERT INTO !PREFIX!_container VALUES (112, 6, 56, 0);
INSERT INTO !PREFIX!_container VALUES (113, 6, 57, 0);
INSERT INTO !PREFIX!_container VALUES (114, 6, 58, 0);
INSERT INTO !PREFIX!_container VALUES (115, 6, 59, 0);
INSERT INTO !PREFIX!_container VALUES (116, 6, 60, 21);
INSERT INTO !PREFIX!_container VALUES (117, 6, 70, 8);
INSERT INTO !PREFIX!_container VALUES (118, 6, 75, 11);
INSERT INTO !PREFIX!_container VALUES (119, 6, 76, 4);
INSERT INTO !PREFIX!_container VALUES (120, 6, 80, 7);
INSERT INTO !PREFIX!_container VALUES (121, 7, 1, 3);
INSERT INTO !PREFIX!_container VALUES (122, 7, 10, 22);
INSERT INTO !PREFIX!_container VALUES (123, 7, 20, 5);
INSERT INTO !PREFIX!_container VALUES (124, 7, 30, 10);
INSERT INTO !PREFIX!_container VALUES (125, 7, 40, 17);
INSERT INTO !PREFIX!_container VALUES (126, 7, 50, 6);
INSERT INTO !PREFIX!_container VALUES (127, 7, 51, 20);
INSERT INTO !PREFIX!_container VALUES (128, 7, 52, 23);
INSERT INTO !PREFIX!_container VALUES (129, 7, 53, 0);
INSERT INTO !PREFIX!_container VALUES (130, 7, 54, 0);
INSERT INTO !PREFIX!_container VALUES (131, 7, 55, 0);
INSERT INTO !PREFIX!_container VALUES (132, 7, 56, 0);
INSERT INTO !PREFIX!_container VALUES (133, 7, 57, 0);
INSERT INTO !PREFIX!_container VALUES (134, 7, 58, 0);
INSERT INTO !PREFIX!_container VALUES (135, 7, 59, 0);
INSERT INTO !PREFIX!_container VALUES (136, 7, 60, 16);
INSERT INTO !PREFIX!_container VALUES (137, 7, 70, 8);
INSERT INTO !PREFIX!_container VALUES (138, 7, 75, 11);
INSERT INTO !PREFIX!_container VALUES (139, 7, 76, 4);
INSERT INTO !PREFIX!_container VALUES (140, 7, 80, 7);
INSERT INTO !PREFIX!_container VALUES (141, 8, 1, 3);
INSERT INTO !PREFIX!_container VALUES (142, 8, 10, 22);
INSERT INTO !PREFIX!_container VALUES (143, 8, 20, 5);
INSERT INTO !PREFIX!_container VALUES (144, 8, 30, 10);
INSERT INTO !PREFIX!_container VALUES (145, 8, 40, 17);
INSERT INTO !PREFIX!_container VALUES (146, 8, 50, 6);
INSERT INTO !PREFIX!_container VALUES (147, 8, 51, 20);
INSERT INTO !PREFIX!_container VALUES (148, 8, 52, 18);
INSERT INTO !PREFIX!_container VALUES (149, 8, 53, 0);
INSERT INTO !PREFIX!_container VALUES (150, 8, 54, 0);
INSERT INTO !PREFIX!_container VALUES (151, 8, 55, 0);
INSERT INTO !PREFIX!_container VALUES (152, 8, 56, 0);
INSERT INTO !PREFIX!_container VALUES (153, 8, 57, 0);
INSERT INTO !PREFIX!_container VALUES (154, 8, 58, 0);
INSERT INTO !PREFIX!_container VALUES (155, 8, 59, 0);
INSERT INTO !PREFIX!_container VALUES (156, 8, 60, 21);
INSERT INTO !PREFIX!_container VALUES (157, 8, 70, 8);
INSERT INTO !PREFIX!_container VALUES (158, 8, 75, 11);
INSERT INTO !PREFIX!_container VALUES (159, 8, 76, 4);
INSERT INTO !PREFIX!_container VALUES (160, 8, 80, 7);
INSERT INTO !PREFIX!_container_conf VALUES (8, 9, 60, '0=http%3A%2F%2Fwww.contenido.org%2Frss%2Fde%2Fnews&1=teaser_right.html&2=3&');
INSERT INTO !PREFIX!_container_conf VALUES (5, 59, 52, '1=2&3=sortdate&16=asc&4=%24C52%24C52CMS_VALUE%5B4%5D&14=&15=&');
INSERT INTO !PREFIX!_container_conf VALUES (9, 43, 60, '0=http%3A%2F%2Fwww.contenido.org%2Frss%2Fde%2Fnews&1=teaser_right.html&2=3&');
INSERT INTO !PREFIX!_container_conf VALUES (10, 50, 52, '0=1&1=5&');
INSERT INTO !PREFIX!_container_conf VALUES (11, 34, 52, '1=1&2=5&3=0&');
INSERT INTO !PREFIX!_container_conf VALUES (13, 60, 60, '0=http%3A%2F%2Fwww.contenido.org%2Frss%2Fde%2Fnews&1=teaser_right.html&2=3&');
INSERT INTO !PREFIX!_container_conf VALUES (15, 16, 52, '0=180&1=180&2=2&3=2&4=&5=bildergalerie%2F&');
INSERT INTO !PREFIX!_container_conf VALUES (16, 31, 52, '0=&2=&1=&3=&4=sendmail&5=&6=&7=&');
INSERT INTO !PREFIX!_container_conf VALUES (17, 47, 52, '0=&2=&1=&3=&4=sendmail&5=&6=&7=&');
